Class: Aws::FraudDetector::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::FraudDetector::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-frauddetector/client.rb,
sig/client.rbs
Overview
An API client for FraudDetector. To construct a client, you need to configure a :region and :credentials.
client = Aws::FraudDetector::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchCreateVariableResponseSuccess, _BatchGetVariableResponseSuccess, _CancelBatchImportJobResponseSuccess, _CancelBatchPredictionJobResponseSuccess, _CreateBatchImportJobResponseSuccess, _CreateBatchPredictionJobResponseSuccess, _CreateDetectorVersionResponseSuccess, _CreateListResponseSuccess, _CreateModelResponseSuccess, _CreateModelVersionResponseSuccess, _CreateRuleResponseSuccess, _CreateVariableResponseSuccess, _DeleteBatchImportJobResponseSuccess, _DeleteBatchPredictionJobResponseSuccess, _DeleteDetectorResponseSuccess, _DeleteDetectorVersionResponseSuccess, _DeleteEntityTypeResponseSuccess, _DeleteEventResponseSuccess, _DeleteEventTypeResponseSuccess, _DeleteEventsByEventTypeResponseSuccess, _DeleteExternalModelResponseSuccess, _DeleteLabelResponseSuccess, _DeleteListResponseSuccess, _DeleteModelResponseSuccess, _DeleteModelVersionResponseSuccess, _DeleteOutcomeResponseSuccess, _DeleteRuleResponseSuccess, _DeleteVariableResponseSuccess, _DescribeDetectorResponseSuccess, _DescribeModelVersionsResponseSuccess, _GetBatchImportJobsResponseSuccess, _GetBatchPredictionJobsResponseSuccess, _GetDeleteEventsByEventTypeStatusResponseSuccess, _GetDetectorVersionResponseSuccess, _GetDetectorsResponseSuccess, _GetEntityTypesResponseSuccess, _GetEventPredictionMetadataResponseSuccess, _GetEventPredictionResponseSuccess, _GetEventResponseSuccess, _GetEventTypesResponseSuccess, _GetExternalModelsResponseSuccess, _GetKMSEncryptionKeyResponseSuccess, _GetLabelsResponseSuccess, _GetListElementsResponseSuccess, _GetListsMetadataResponseSuccess, _GetModelVersionResponseSuccess, _GetModelsResponseSuccess, _GetOutcomesResponseSuccess, _GetRulesResponseSuccess, _GetVariablesResponseSuccess, _ListEventPredictionsResponseSuccess, _ListTagsForResourceResponseSuccess, _PutDetectorResponseSuccess, _PutEntityTypeResponseSuccess, _PutEventTypeResponseSuccess, _PutExternalModelResponseSuccess, _PutKMSEncryptionKeyResponseSuccess, _PutLabelResponseSuccess, _PutOutcomeResponseSuccess, _SendEventResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateDetectorVersionMetadataResponseSuccess, _UpdateDetectorVersionResponseSuccess, _UpdateDetectorVersionStatusResponseSuccess, _UpdateEventLabelResponseSuccess, _UpdateListResponseSuccess, _UpdateModelResponseSuccess, _UpdateModelVersionResponseSuccess, _UpdateModelVersionStatusResponseSuccess, _UpdateRuleMetadataResponseSuccess, _UpdateRuleVersionResponseSuccess, _UpdateVariableResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_create_variable(params = {}) ⇒ Types::BatchCreateVariableResult
Creates a batch of variables.
-
#batch_get_variable(params = {}) ⇒ Types::BatchGetVariableResult
Gets a batch of variables.
-
#cancel_batch_import_job(params = {}) ⇒ Struct
Cancels an in-progress batch import job.
-
#cancel_batch_prediction_job(params = {}) ⇒ Struct
Cancels the specified batch prediction job.
-
#create_batch_import_job(params = {}) ⇒ Struct
Creates a batch import job.
-
#create_batch_prediction_job(params = {}) ⇒ Struct
Creates a batch prediction job.
-
#create_detector_version(params = {}) ⇒ Types::CreateDetectorVersionResult
Creates a detector version.
-
#create_list(params = {}) ⇒ Struct
Creates a list.
-
#create_model(params = {}) ⇒ Struct
Creates a model using the specified model type.
-
#create_model_version(params = {}) ⇒ Types::CreateModelVersionResult
Creates a version of the model using the specified model type and model id.
-
#create_rule(params = {}) ⇒ Types::CreateRuleResult
Creates a rule for use with the specified detector.
-
#create_variable(params = {}) ⇒ Struct
Creates a variable.
-
#delete_batch_import_job(params = {}) ⇒ Struct
Deletes the specified batch import job ID record.
-
#delete_batch_prediction_job(params = {}) ⇒ Struct
Deletes a batch prediction job.
-
#delete_detector(params = {}) ⇒ Struct
Deletes the detector.
-
#delete_detector_version(params = {}) ⇒ Struct
Deletes the detector version.
-
#delete_entity_type(params = {}) ⇒ Struct
Deletes an entity type.
-
#delete_event(params = {}) ⇒ Struct
Deletes the specified event.
-
#delete_event_type(params = {}) ⇒ Struct
Deletes an event type.
-
#delete_events_by_event_type(params = {}) ⇒ Types::DeleteEventsByEventTypeResult
Deletes all events of a particular event type.
-
#delete_external_model(params = {}) ⇒ Struct
Removes a SageMaker model from Amazon Fraud Detector.
-
#delete_label(params = {}) ⇒ Struct
Deletes a label.
-
#delete_list(params = {}) ⇒ Struct
Deletes the list, provided it is not used in a rule.
-
#delete_model(params = {}) ⇒ Struct
Deletes a model.
-
#delete_model_version(params = {}) ⇒ Struct
Deletes a model version.
-
#delete_outcome(params = {}) ⇒ Struct
Deletes an outcome.
-
#delete_rule(params = {}) ⇒ Struct
Deletes the rule.
-
#delete_variable(params = {}) ⇒ Struct
Deletes a variable.
-
#describe_detector(params = {}) ⇒ Types::DescribeDetectorResult
Gets all versions for a specified detector.
-
#describe_model_versions(params = {}) ⇒ Types::DescribeModelVersionsResult
Gets all of the model versions for the specified model type or for the specified model type and model ID.
-
#get_batch_import_jobs(params = {}) ⇒ Types::GetBatchImportJobsResult
Gets all batch import jobs or a specific job of the specified ID.
-
#get_batch_prediction_jobs(params = {}) ⇒ Types::GetBatchPredictionJobsResult
Gets all batch prediction jobs or a specific job if you specify a job ID.
-
#get_delete_events_by_event_type_status(params = {}) ⇒ Types::GetDeleteEventsByEventTypeStatusResult
Retrieves the status of a
DeleteEventsByEventTypeaction. -
#get_detector_version(params = {}) ⇒ Types::GetDetectorVersionResult
Gets a particular detector version.
-
#get_detectors(params = {}) ⇒ Types::GetDetectorsResult
Gets all detectors or a single detector if a
detectorIdis specified. -
#get_entity_types(params = {}) ⇒ Types::GetEntityTypesResult
Gets all entity types or a specific entity type if a name is specified.
-
#get_event(params = {}) ⇒ Types::GetEventResult
Retrieves details of events stored with Amazon Fraud Detector.
-
#get_event_prediction(params = {}) ⇒ Types::GetEventPredictionResult
Evaluates an event against a detector version.
-
#get_event_prediction_metadata(params = {}) ⇒ Types::GetEventPredictionMetadataResult
Gets details of the past fraud predictions for the specified event ID, event type, detector ID, and detector version ID that was generated in the specified time period.
-
#get_event_types(params = {}) ⇒ Types::GetEventTypesResult
Gets all event types or a specific event type if name is provided.
-
#get_external_models(params = {}) ⇒ Types::GetExternalModelsResult
Gets the details for one or more Amazon SageMaker models that have been imported into the service.
-
#get_kms_encryption_key(params = {}) ⇒ Types::GetKMSEncryptionKeyResult
Gets the encryption key if a KMS key has been specified to be used to encrypt content in Amazon Fraud Detector.
-
#get_labels(params = {}) ⇒ Types::GetLabelsResult
Gets all labels or a specific label if name is provided.
-
#get_list_elements(params = {}) ⇒ Types::GetListElementsResult
Gets all the elements in the specified list.
-
#get_lists_metadata(params = {}) ⇒ Types::GetListsMetadataResult
Gets the metadata of either all the lists under the account or the specified list.
-
#get_model_version(params = {}) ⇒ Types::GetModelVersionResult
Gets the details of the specified model version.
-
#get_models(params = {}) ⇒ Types::GetModelsResult
Gets one or more models.
-
#get_outcomes(params = {}) ⇒ Types::GetOutcomesResult
Gets one or more outcomes.
-
#get_rules(params = {}) ⇒ Types::GetRulesResult
Get all rules for a detector (paginated) if
ruleIdandruleVersionare not specified. -
#get_variables(params = {}) ⇒ Types::GetVariablesResult
Gets all of the variables or the specific variable.
-
#list_event_predictions(params = {}) ⇒ Types::ListEventPredictionsResult
Gets a list of past predictions.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResult
Lists all tags associated with the resource.
-
#put_detector(params = {}) ⇒ Struct
Creates or updates a detector.
-
#put_entity_type(params = {}) ⇒ Struct
Creates or updates an entity type.
-
#put_event_type(params = {}) ⇒ Struct
Creates or updates an event type.
-
#put_external_model(params = {}) ⇒ Struct
Creates or updates an Amazon SageMaker model endpoint.
-
#put_kms_encryption_key(params = {}) ⇒ Struct
Specifies the KMS key to be used to encrypt content in Amazon Fraud Detector.
-
#put_label(params = {}) ⇒ Struct
Creates or updates label.
-
#put_outcome(params = {}) ⇒ Struct
Creates or updates an outcome.
-
#send_event(params = {}) ⇒ Struct
Stores events in Amazon Fraud Detector without generating fraud predictions for those events.
-
#tag_resource(params = {}) ⇒ Struct
Assigns tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_detector_version(params = {}) ⇒ Struct
Updates a detector version.
-
#update_detector_version_metadata(params = {}) ⇒ Struct
Updates the detector version's description.
-
#update_detector_version_status(params = {}) ⇒ Struct
Updates the detector version’s status.
-
#update_event_label(params = {}) ⇒ Struct
Updates the specified event with a new label.
-
#update_list(params = {}) ⇒ Struct
Updates a list.
-
#update_model(params = {}) ⇒ Struct
Updates model description.
-
#update_model_version(params = {}) ⇒ Types::UpdateModelVersionResult
Updates a model version.
-
#update_model_version_status(params = {}) ⇒ Struct
Updates the status of a model version.
-
#update_rule_metadata(params = {}) ⇒ Struct
Updates a rule's metadata.
-
#update_rule_version(params = {}) ⇒ Types::UpdateRuleVersionResult
Updates a rule version resulting in a new rule version.
-
#update_variable(params = {}) ⇒ Struct
Updates a variable.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4046 4047 4048 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 4046 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4049 4050 4051 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 4049 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#batch_create_variable(params = {}) ⇒ Types::BatchCreateVariableResult
Creates a batch of variables.
87 |
# File 'sig/client.rbs', line 87
def batch_create_variable: (
|
#batch_get_variable(params = {}) ⇒ Types::BatchGetVariableResult
Gets a batch of variables.
113 |
# File 'sig/client.rbs', line 113
def batch_get_variable: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 4029 4030 4031 4032 4033 4034 4035 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 4019 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::FraudDetector') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-frauddetector' context[:gem_version] = '1.88.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_batch_import_job(params = {}) ⇒ Struct
Cancels an in-progress batch import job.
122 |
# File 'sig/client.rbs', line 122
def cancel_batch_import_job: (
|
#cancel_batch_prediction_job(params = {}) ⇒ Struct
Cancels the specified batch prediction job.
131 |
# File 'sig/client.rbs', line 131
def cancel_batch_prediction_job: (
|
#create_batch_import_job(params = {}) ⇒ Struct
Creates a batch import job.
140 |
# File 'sig/client.rbs', line 140
def create_batch_import_job: (
|
#create_batch_prediction_job(params = {}) ⇒ Struct
Creates a batch prediction job.
159 |
# File 'sig/client.rbs', line 159
def create_batch_prediction_job: (
|
#create_detector_version(params = {}) ⇒ Types::CreateDetectorVersionResult
Creates a detector version. The detector version starts in a DRAFT
status.
183 |
# File 'sig/client.rbs', line 183
def create_detector_version: (
|
#create_list(params = {}) ⇒ Struct
Creates a list.
List is a set of input data for a variable in your event dataset. You use the input data in a rule that's associated with your detector. For more information, see Lists.
216 |
# File 'sig/client.rbs', line 216
def create_list: (
|
#create_model(params = {}) ⇒ Struct
Creates a model using the specified model type.
234 |
# File 'sig/client.rbs', line 234
def create_model: (
|
#create_model_version(params = {}) ⇒ Types::CreateModelVersionResult
Creates a version of the model using the specified model type and model id.
256 |
# File 'sig/client.rbs', line 256
def create_model_version: (
|
#create_rule(params = {}) ⇒ Types::CreateRuleResult
Creates a rule for use with the specified detector.
291 |
# File 'sig/client.rbs', line 291
def create_rule: (
|
#create_variable(params = {}) ⇒ Struct
Creates a variable.
311 |
# File 'sig/client.rbs', line 311
def create_variable: (
|
#delete_batch_import_job(params = {}) ⇒ Struct
Deletes the specified batch import job ID record. This action does not delete the data that was batch imported.
331 |
# File 'sig/client.rbs', line 331
def delete_batch_import_job: (
|
#delete_batch_prediction_job(params = {}) ⇒ Struct
Deletes a batch prediction job.
340 |
# File 'sig/client.rbs', line 340
def delete_batch_prediction_job: (
|
#delete_detector(params = {}) ⇒ Struct
Deletes the detector. Before deleting a detector, you must first delete all detector versions and rule versions associated with the detector.
When you delete a detector, Amazon Fraud Detector permanently deletes the detector and the data is no longer stored in Amazon Fraud Detector.
349 |
# File 'sig/client.rbs', line 349
def delete_detector: (
|
#delete_detector_version(params = {}) ⇒ Struct
Deletes the detector version. You cannot delete detector versions that
are in ACTIVE status.
When you delete a detector version, Amazon Fraud Detector permanently deletes the detector and the data is no longer stored in Amazon Fraud Detector.
358 |
# File 'sig/client.rbs', line 358
def delete_detector_version: (
|
#delete_entity_type(params = {}) ⇒ Struct
Deletes an entity type.
You cannot delete an entity type that is included in an event type.
When you delete an entity type, Amazon Fraud Detector permanently deletes that entity type and the data is no longer stored in Amazon Fraud Detector.
368 |
# File 'sig/client.rbs', line 368
def delete_entity_type: (
|
#delete_event(params = {}) ⇒ Struct
Deletes the specified event.
When you delete an event, Amazon Fraud Detector permanently deletes
that event and the event data is no longer stored in Amazon Fraud
Detector. If deleteAuditHistory is True, event data is available
through search for up to 30 seconds after the delete operation is
completed.
377 |
# File 'sig/client.rbs', line 377
def delete_event: (
|
#delete_event_type(params = {}) ⇒ Struct
Deletes an event type.
You cannot delete an event type that is used in a detector or a model.
When you delete an event type, Amazon Fraud Detector permanently deletes that event type and the data is no longer stored in Amazon Fraud Detector.
388 |
# File 'sig/client.rbs', line 388
def delete_event_type: (
|
#delete_events_by_event_type(params = {}) ⇒ Types::DeleteEventsByEventTypeResult
Deletes all events of a particular event type.
399 |
# File 'sig/client.rbs', line 399
def delete_events_by_event_type: (
|
#delete_external_model(params = {}) ⇒ Struct
Removes a SageMaker model from Amazon Fraud Detector.
You can remove an Amazon SageMaker model if it is not associated with a detector version. Removing a SageMaker model disconnects it from Amazon Fraud Detector, but the model remains available in SageMaker.
408 |
# File 'sig/client.rbs', line 408
def delete_external_model: (
|
#delete_label(params = {}) ⇒ Struct
Deletes a label.
You cannot delete labels that are included in an event type in Amazon Fraud Detector.
You cannot delete a label assigned to an event ID. You must first delete the relevant event ID.
When you delete a label, Amazon Fraud Detector permanently deletes that label and the data is no longer stored in Amazon Fraud Detector.
417 |
# File 'sig/client.rbs', line 417
def delete_label: (
|
#delete_list(params = {}) ⇒ Struct
Deletes the list, provided it is not used in a rule.
When you delete a list, Amazon Fraud Detector permanently deletes that list and the elements in the list.
426 |
# File 'sig/client.rbs', line 426
def delete_list: (
|
#delete_model(params = {}) ⇒ Struct
Deletes a model.
You can delete models and model versions in Amazon Fraud Detector, provided that they are not associated with a detector version.
When you delete a model, Amazon Fraud Detector permanently deletes that model and the data is no longer stored in Amazon Fraud Detector.
435 |
# File 'sig/client.rbs', line 435
def delete_model: (
|
#delete_model_version(params = {}) ⇒ Struct
Deletes a model version.
You can delete models and model versions in Amazon Fraud Detector, provided that they are not associated with a detector version.
When you delete a model version, Amazon Fraud Detector permanently deletes that model version and the data is no longer stored in Amazon Fraud Detector.
445 |
# File 'sig/client.rbs', line 445
def delete_model_version: (
|
#delete_outcome(params = {}) ⇒ Struct
Deletes an outcome.
You cannot delete an outcome that is used in a rule version.
When you delete an outcome, Amazon Fraud Detector permanently deletes that outcome and the data is no longer stored in Amazon Fraud Detector.
456 |
# File 'sig/client.rbs', line 456
def delete_outcome: (
|
#delete_rule(params = {}) ⇒ Struct
Deletes the rule. You cannot delete a rule if it is used by an
ACTIVE or INACTIVE detector version.
When you delete a rule, Amazon Fraud Detector permanently deletes that rule and the data is no longer stored in Amazon Fraud Detector.
465 |
# File 'sig/client.rbs', line 465
def delete_rule: (
|
#delete_variable(params = {}) ⇒ Struct
Deletes a variable.
You can't delete variables that are included in an event type in Amazon Fraud Detector.
Amazon Fraud Detector automatically deletes model output variables and SageMaker model output variables when you delete the model. You can't delete these variables manually.
When you delete a variable, Amazon Fraud Detector permanently deletes that variable and the data is no longer stored in Amazon Fraud Detector.
478 |
# File 'sig/client.rbs', line 478
def delete_variable: (
|
#describe_detector(params = {}) ⇒ Types::DescribeDetectorResult
Gets all versions for a specified detector.
491 |
# File 'sig/client.rbs', line 491
def describe_detector: (
|
#describe_model_versions(params = {}) ⇒ Types::DescribeModelVersionsResult
Gets all of the model versions for the specified model type or for the specified model type and model ID. You can also get details for a single, specified model version.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
504 |
# File 'sig/client.rbs', line 504
def describe_model_versions: (
|
#get_batch_import_jobs(params = {}) ⇒ Types::GetBatchImportJobsResult
Gets all batch import jobs or a specific job of the specified ID. This
is a paginated API. If you provide a null maxResults, this action
retrieves a maximum of 50 records per page. If you provide a
maxResults, the value must be between 1 and 50. To get the next page
results, provide the pagination token from the
GetBatchImportJobsResponse as part of your request. A null
pagination token fetches the records from the beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
519 |
# File 'sig/client.rbs', line 519
def get_batch_import_jobs: (
|
#get_batch_prediction_jobs(params = {}) ⇒ Types::GetBatchPredictionJobsResult
Gets all batch prediction jobs or a specific job if you specify a job ID. This is a paginated API. If you provide a null maxResults, this action retrieves a maximum of 50 records per page. If you provide a maxResults, the value must be between 1 and 50. To get the next page results, provide the pagination token from the GetBatchPredictionJobsResponse as part of your request. A null pagination token fetches the records from the beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
532 |
# File 'sig/client.rbs', line 532
def get_batch_prediction_jobs: (
|
#get_delete_events_by_event_type_status(params = {}) ⇒ Types::GetDeleteEventsByEventTypeStatusResult
Retrieves the status of a DeleteEventsByEventType action.
545 |
# File 'sig/client.rbs', line 545
def get_delete_events_by_event_type_status: (
|
#get_detector_version(params = {}) ⇒ Types::GetDetectorVersionResult
Gets a particular detector version.
565 |
# File 'sig/client.rbs', line 565
def get_detector_version: (
|
#get_detectors(params = {}) ⇒ Types::GetDetectorsResult
Gets all detectors or a single detector if a detectorId is
specified. This is a paginated API. If you provide a null
maxResults, this action retrieves a maximum of 10 records per page.
If you provide a maxResults, the value must be between 5 and 10. To
get the next page results, provide the pagination token from the
GetDetectorsResponse as part of your request. A null pagination
token fetches the records from the beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
577 |
# File 'sig/client.rbs', line 577
def get_detectors: (
|
#get_entity_types(params = {}) ⇒ Types::GetEntityTypesResult
Gets all entity types or a specific entity type if a name is
specified. This is a paginated API. If you provide a null
maxResults, this action retrieves a maximum of 10 records per page.
If you provide a maxResults, the value must be between 5 and 10. To
get the next page results, provide the pagination token from the
GetEntityTypesResponse as part of your request. A null pagination
token fetches the records from the beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
590 |
# File 'sig/client.rbs', line 590
def get_entity_types: (
|
#get_event(params = {}) ⇒ Types::GetEventResult
Retrieves details of events stored with Amazon Fraud Detector. This action does not retrieve prediction results.
602 |
# File 'sig/client.rbs', line 602
def get_event: (
|
#get_event_prediction(params = {}) ⇒ Types::GetEventPredictionResult
Evaluates an event against a detector version. If a version ID is not
provided, the detector’s (ACTIVE) version is used.
615 |
# File 'sig/client.rbs', line 615
def get_event_prediction: (
|
#get_event_prediction_metadata(params = {}) ⇒ Types::GetEventPredictionMetadataResult
Gets details of the past fraud predictions for the specified event ID, event type, detector ID, and detector version ID that was generated in the specified time period.
654 |
# File 'sig/client.rbs', line 654
def get_event_prediction_metadata: (
|
#get_event_types(params = {}) ⇒ Types::GetEventTypesResult
Gets all event types or a specific event type if name is provided.
This is a paginated API. If you provide a null maxResults, this
action retrieves a maximum of 10 records per page. If you provide a
maxResults, the value must be between 5 and 10. To get the next page
results, provide the pagination token from the GetEventTypesResponse
as part of your request. A null pagination token fetches the records
from the beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
669 |
# File 'sig/client.rbs', line 669
def get_event_types: (
|
#get_external_models(params = {}) ⇒ Types::GetExternalModelsResult
Gets the details for one or more Amazon SageMaker models that have
been imported into the service. This is a paginated API. If you
provide a null maxResults, this actions retrieves a maximum of 10
records per page. If you provide a maxResults, the value must be
between 5 and 10. To get the next page results, provide the pagination
token from the GetExternalModelsResult as part of your request. A
null pagination token fetches the records from the beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
682 |
# File 'sig/client.rbs', line 682
def get_external_models: (
|
#get_kms_encryption_key(params = {}) ⇒ Types::GetKMSEncryptionKeyResult
Gets the encryption key if a KMS key has been specified to be used to encrypt content in Amazon Fraud Detector.
694 695 |
# File 'sig/client.rbs', line 694
def get_kms_encryption_key: () -> _GetKMSEncryptionKeyResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _GetKMSEncryptionKeyResponseSuccess
|
#get_labels(params = {}) ⇒ Types::GetLabelsResult
Gets all labels or a specific label if name is provided. This is a
paginated API. If you provide a null maxResults, this action
retrieves a maximum of 50 records per page. If you provide a
maxResults, the value must be between 10 and 50. To get the next
page results, provide the pagination token from the
GetGetLabelsResponse as part of your request. A null pagination
token fetches the records from the beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
703 |
# File 'sig/client.rbs', line 703
def get_labels: (
|
#get_list_elements(params = {}) ⇒ Types::GetListElementsResult
Gets all the elements in the specified list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
716 |
# File 'sig/client.rbs', line 716
def get_list_elements: (
|
#get_lists_metadata(params = {}) ⇒ Types::GetListsMetadataResult
Gets the metadata of either all the lists under the account or the specified list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
729 |
# File 'sig/client.rbs', line 729
def get_lists_metadata: (
|
#get_model_version(params = {}) ⇒ Types::GetModelVersionResult
Gets the details of the specified model version.
749 |
# File 'sig/client.rbs', line 749
def get_model_version: (
|
#get_models(params = {}) ⇒ Types::GetModelsResult
Gets one or more models. Gets all models for the Amazon Web Services account if no model type and no model id provided. Gets all models for the Amazon Web Services account and model type, if the model type is specified but model id is not provided. Gets a specific model if (model type, model id) tuple is specified.
This is a paginated API. If you provide a null maxResults, this
action retrieves a maximum of 10 records per page. If you provide a
maxResults, the value must be between 1 and 10. To get the next page
results, provide the pagination token from the response as part of
your request. A null pagination token fetches the records from the
beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
762 |
# File 'sig/client.rbs', line 762
def get_models: (
|
#get_outcomes(params = {}) ⇒ Types::GetOutcomesResult
Gets one or more outcomes. This is a paginated API. If you provide a
null maxResults, this actions retrieves a maximum of 100 records per
page. If you provide a maxResults, the value must be between 50 and
100. To get the next page results, provide the pagination token from
the GetOutcomesResult as part of your request. A null pagination
token fetches the records from the beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
776 |
# File 'sig/client.rbs', line 776
def get_outcomes: (
|
#get_rules(params = {}) ⇒ Types::GetRulesResult
Get all rules for a detector (paginated) if ruleId and ruleVersion
are not specified. Gets all rules for the detector and the ruleId if
present (paginated). Gets a specific rule if both the ruleId and the
ruleVersion are specified.
This is a paginated API. Providing null maxResults results in retrieving maximum of 100 records per page. If you provide maxResults the value must be between 50 and 100. To get the next page result, a provide a pagination token from GetRulesResult as part of your request. Null pagination token fetches the records from the beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
789 |
# File 'sig/client.rbs', line 789
def get_rules: (
|
#get_variables(params = {}) ⇒ Types::GetVariablesResult
Gets all of the variables or the specific variable. This is a
paginated API. Providing null maxSizePerPage results in retrieving
maximum of 100 records per page. If you provide maxSizePerPage the
value must be between 50 and 100. To get the next page result, a
provide a pagination token from GetVariablesResult as part of your
request. Null pagination token fetches the records from the beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
804 |
# File 'sig/client.rbs', line 804
def get_variables: (
|
#list_event_predictions(params = {}) ⇒ Types::ListEventPredictionsResult
Gets a list of past predictions. The list can be filtered by detector ID, detector version ID, event ID, event type, or by specifying a time period. If filter is not specified, the most recent prediction is returned.
For example, the following filter lists all past predictions for xyz
event type - { "eventType":{ "value": "xyz" }” }
This is a paginated API. If you provide a null maxResults, this
action will retrieve a maximum of 10 records per page. If you provide
a maxResults, the value must be between 50 and 100. To get the next
page results, provide the nextToken from the response as part of
your request. A null nextToken fetches the records from the
beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
817 |
# File 'sig/client.rbs', line 817
def list_event_predictions: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResult
Lists all tags associated with the resource. This is a paginated API. To get the next page results, provide the pagination token from the response as part of your request. A null pagination token fetches the records from the beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
845 |
# File 'sig/client.rbs', line 845
def list_tags_for_resource: (
|
#put_detector(params = {}) ⇒ Struct
Creates or updates a detector.
856 |
# File 'sig/client.rbs', line 856
def put_detector: (
|
#put_entity_type(params = {}) ⇒ Struct
Creates or updates an entity type. An entity represents who is performing the event. As part of a fraud prediction, you pass the entity ID to indicate the specific entity who performed the event. An entity type classifies the entity. Example classifications include customer, merchant, or account.
873 |
# File 'sig/client.rbs', line 873
def put_entity_type: (
|
#put_event_type(params = {}) ⇒ Struct
Creates or updates an event type. An event is a business activity that is evaluated for fraud risk. With Amazon Fraud Detector, you generate fraud predictions for events. An event type defines the structure for an event sent to Amazon Fraud Detector. This includes the variables sent as part of the event, the entity performing the event (such as a customer), and the labels that classify the event. Example event types include online payment transactions, account registrations, and authentications.
889 |
# File 'sig/client.rbs', line 889
def put_event_type: (
|
#put_external_model(params = {}) ⇒ Struct
Creates or updates an Amazon SageMaker model endpoint. You can also use this action to update the configuration of the model endpoint, including the IAM role and/or the mapped variables.
912 |
# File 'sig/client.rbs', line 912
def put_external_model: (
|
#put_kms_encryption_key(params = {}) ⇒ Struct
Specifies the KMS key to be used to encrypt content in Amazon Fraud Detector.
942 |
# File 'sig/client.rbs', line 942
def put_kms_encryption_key: (
|
#put_label(params = {}) ⇒ Struct
Creates or updates label. A label classifies an event as fraudulent or legitimate. Labels are associated with event types and used to train supervised machine learning models in Amazon Fraud Detector.
951 |
# File 'sig/client.rbs', line 951
def put_label: (
|
#put_outcome(params = {}) ⇒ Struct
Creates or updates an outcome.
967 |
# File 'sig/client.rbs', line 967
def put_outcome: (
|
#send_event(params = {}) ⇒ Struct
Stores events in Amazon Fraud Detector without generating fraud
predictions for those events. For example, you can use SendEvent to
upload a historical dataset, which you can then later use to train a
model.
983 |
# File 'sig/client.rbs', line 983
def send_event: (
|
#tag_resource(params = {}) ⇒ Struct
Assigns tags to a resource.
1003 |
# File 'sig/client.rbs', line 1003
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
1018 |
# File 'sig/client.rbs', line 1018
def untag_resource: (
|
#update_detector_version(params = {}) ⇒ Struct
Updates a detector version. The detector version attributes that you
can update include models, external model endpoints, rules, rule
execution mode, and description. You can only update a DRAFT
detector version.
1028 |
# File 'sig/client.rbs', line 1028
def update_detector_version: (
|
#update_detector_version_metadata(params = {}) ⇒ Struct
Updates the detector version's description. You can update the
metadata for any detector version (DRAFT, ACTIVE, or INACTIVE).
1056 |
# File 'sig/client.rbs', line 1056
def update_detector_version_metadata: (
|
#update_detector_version_status(params = {}) ⇒ Struct
Updates the detector version’s status. You can perform the following
promotions or demotions using UpdateDetectorVersionStatus: DRAFT
to ACTIVE, ACTIVE to INACTIVE, and INACTIVE to ACTIVE.
1067 |
# File 'sig/client.rbs', line 1067
def update_detector_version_status: (
|
#update_event_label(params = {}) ⇒ Struct
Updates the specified event with a new label.
1078 |
# File 'sig/client.rbs', line 1078
def update_event_label: (
|
#update_list(params = {}) ⇒ Struct
Updates a list.
1090 |
# File 'sig/client.rbs', line 1090
def update_list: (
|
#update_model(params = {}) ⇒ Struct
Updates model description.
1103 |
# File 'sig/client.rbs', line 1103
def update_model: (
|
#update_model_version(params = {}) ⇒ Types::UpdateModelVersionResult
Updates a model version. Updating a model version retrains an existing model version using updated training data and produces a new minor version of the model. You can update the training data set location and data access role attributes using this action. This action creates and trains a new minor version of the model, for example version 1.01, 1.02, 1.03.
1118 |
# File 'sig/client.rbs', line 1118
def update_model_version: (
|
#update_model_version_status(params = {}) ⇒ Struct
Updates the status of a model version.
You can perform the following status updates:
-
Change the
TRAINING_IN_PROGRESSstatus toTRAINING_CANCELLED. -
Change the
TRAINING_COMPLETEstatus toACTIVE. -
Change
ACTIVEtoINACTIVE.
1145 |
# File 'sig/client.rbs', line 1145
def update_model_version_status: (
|
#update_rule_metadata(params = {}) ⇒ Struct
Updates a rule's metadata. The description attribute can be updated.
1157 |
# File 'sig/client.rbs', line 1157
def update_rule_metadata: (
|
#update_rule_version(params = {}) ⇒ Types::UpdateRuleVersionResult
Updates a rule version resulting in a new rule version. Updates a rule version resulting in a new rule version (version 1, 2, 3 ...).
1172 |
# File 'sig/client.rbs', line 1172
def update_rule_version: (
|
#update_variable(params = {}) ⇒ Struct
Updates a variable.
1195 |
# File 'sig/client.rbs', line 1195
def update_variable: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4039 4040 4041 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 4039 def waiter_names [] end |