Class: Aws::FraudDetector::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::FraudDetector::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-frauddetector/client.rb
Overview
An API client for FraudDetector. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::FraudDetector::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_create_variable(params = {}) ⇒ Types::BatchCreateVariableResult
Creates a batch of variables.
-
#batch_get_variable(params = {}) ⇒ Types::BatchGetVariableResult
Gets a batch of variables.
-
#cancel_batch_import_job(params = {}) ⇒ Struct
Cancels an in-progress batch import job.
-
#cancel_batch_prediction_job(params = {}) ⇒ Struct
Cancels the specified batch prediction job.
-
#create_batch_import_job(params = {}) ⇒ Struct
Creates a batch import job.
-
#create_batch_prediction_job(params = {}) ⇒ Struct
Creates a batch prediction job.
-
#create_detector_version(params = {}) ⇒ Types::CreateDetectorVersionResult
Creates a detector version.
-
#create_list(params = {}) ⇒ Struct
Creates a list.
-
#create_model(params = {}) ⇒ Struct
Creates a model using the specified model type.
-
#create_model_version(params = {}) ⇒ Types::CreateModelVersionResult
Creates a version of the model using the specified model type and model id.
-
#create_rule(params = {}) ⇒ Types::CreateRuleResult
Creates a rule for use with the specified detector.
-
#create_variable(params = {}) ⇒ Struct
Creates a variable.
-
#delete_batch_import_job(params = {}) ⇒ Struct
Deletes the specified batch import job ID record.
-
#delete_batch_prediction_job(params = {}) ⇒ Struct
Deletes a batch prediction job.
-
#delete_detector(params = {}) ⇒ Struct
Deletes the detector.
-
#delete_detector_version(params = {}) ⇒ Struct
Deletes the detector version.
-
#delete_entity_type(params = {}) ⇒ Struct
Deletes an entity type.
-
#delete_event(params = {}) ⇒ Struct
Deletes the specified event.
-
#delete_event_type(params = {}) ⇒ Struct
Deletes an event type.
-
#delete_events_by_event_type(params = {}) ⇒ Types::DeleteEventsByEventTypeResult
Deletes all events of a particular event type.
-
#delete_external_model(params = {}) ⇒ Struct
Removes a SageMaker model from Amazon Fraud Detector.
-
#delete_label(params = {}) ⇒ Struct
Deletes a label.
-
#delete_list(params = {}) ⇒ Struct
Deletes the list, provided it is not used in a rule.
-
#delete_model(params = {}) ⇒ Struct
Deletes a model.
-
#delete_model_version(params = {}) ⇒ Struct
Deletes a model version.
-
#delete_outcome(params = {}) ⇒ Struct
Deletes an outcome.
-
#delete_rule(params = {}) ⇒ Struct
Deletes the rule.
-
#delete_variable(params = {}) ⇒ Struct
Deletes a variable.
-
#describe_detector(params = {}) ⇒ Types::DescribeDetectorResult
Gets all versions for a specified detector.
-
#describe_model_versions(params = {}) ⇒ Types::DescribeModelVersionsResult
Gets all of the model versions for the specified model type or for the specified model type and model ID.
-
#get_batch_import_jobs(params = {}) ⇒ Types::GetBatchImportJobsResult
Gets all batch import jobs or a specific job of the specified ID.
-
#get_batch_prediction_jobs(params = {}) ⇒ Types::GetBatchPredictionJobsResult
Gets all batch prediction jobs or a specific job if you specify a job ID.
-
#get_delete_events_by_event_type_status(params = {}) ⇒ Types::GetDeleteEventsByEventTypeStatusResult
Retrieves the status of a ‘DeleteEventsByEventType` action.
-
#get_detector_version(params = {}) ⇒ Types::GetDetectorVersionResult
Gets a particular detector version.
-
#get_detectors(params = {}) ⇒ Types::GetDetectorsResult
Gets all detectors or a single detector if a ‘detectorId` is specified.
-
#get_entity_types(params = {}) ⇒ Types::GetEntityTypesResult
Gets all entity types or a specific entity type if a name is specified.
-
#get_event(params = {}) ⇒ Types::GetEventResult
Retrieves details of events stored with Amazon Fraud Detector.
-
#get_event_prediction(params = {}) ⇒ Types::GetEventPredictionResult
Evaluates an event against a detector version.
-
#get_event_prediction_metadata(params = {}) ⇒ Types::GetEventPredictionMetadataResult
Gets details of the past fraud predictions for the specified event ID, event type, detector ID, and detector version ID that was generated in the specified time period.
-
#get_event_types(params = {}) ⇒ Types::GetEventTypesResult
Gets all event types or a specific event type if name is provided.
-
#get_external_models(params = {}) ⇒ Types::GetExternalModelsResult
Gets the details for one or more Amazon SageMaker models that have been imported into the service.
-
#get_kms_encryption_key(params = {}) ⇒ Types::GetKMSEncryptionKeyResult
Gets the encryption key if a KMS key has been specified to be used to encrypt content in Amazon Fraud Detector.
-
#get_labels(params = {}) ⇒ Types::GetLabelsResult
Gets all labels or a specific label if name is provided.
-
#get_list_elements(params = {}) ⇒ Types::GetListElementsResult
Gets all the elements in the specified list.
-
#get_lists_metadata(params = {}) ⇒ Types::GetListsMetadataResult
Gets the metadata of either all the lists under the account or the specified list.
-
#get_model_version(params = {}) ⇒ Types::GetModelVersionResult
Gets the details of the specified model version.
-
#get_models(params = {}) ⇒ Types::GetModelsResult
Gets one or more models.
-
#get_outcomes(params = {}) ⇒ Types::GetOutcomesResult
Gets one or more outcomes.
-
#get_rules(params = {}) ⇒ Types::GetRulesResult
Get all rules for a detector (paginated) if ‘ruleId` and `ruleVersion` are not specified.
-
#get_variables(params = {}) ⇒ Types::GetVariablesResult
Gets all of the variables or the specific variable.
-
#list_event_predictions(params = {}) ⇒ Types::ListEventPredictionsResult
Gets a list of past predictions.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResult
Lists all tags associated with the resource.
-
#put_detector(params = {}) ⇒ Struct
Creates or updates a detector.
-
#put_entity_type(params = {}) ⇒ Struct
Creates or updates an entity type.
-
#put_event_type(params = {}) ⇒ Struct
Creates or updates an event type.
-
#put_external_model(params = {}) ⇒ Struct
Creates or updates an Amazon SageMaker model endpoint.
-
#put_kms_encryption_key(params = {}) ⇒ Struct
Specifies the KMS key to be used to encrypt content in Amazon Fraud Detector.
-
#put_label(params = {}) ⇒ Struct
Creates or updates label.
-
#put_outcome(params = {}) ⇒ Struct
Creates or updates an outcome.
-
#send_event(params = {}) ⇒ Struct
Stores events in Amazon Fraud Detector without generating fraud predictions for those events.
-
#tag_resource(params = {}) ⇒ Struct
Assigns tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_detector_version(params = {}) ⇒ Struct
Updates a detector version.
-
#update_detector_version_metadata(params = {}) ⇒ Struct
Updates the detector version’s description.
-
#update_detector_version_status(params = {}) ⇒ Struct
Updates the detector version’s status.
-
#update_event_label(params = {}) ⇒ Struct
Updates the specified event with a new label.
-
#update_list(params = {}) ⇒ Struct
Updates a list.
-
#update_model(params = {}) ⇒ Struct
Updates model description.
-
#update_model_version(params = {}) ⇒ Types::UpdateModelVersionResult
Updates a model version.
-
#update_model_version_status(params = {}) ⇒ Struct
Updates the status of a model version.
-
#update_rule_metadata(params = {}) ⇒ Struct
Updates a rule’s metadata.
-
#update_rule_version(params = {}) ⇒ Types::UpdateRuleVersionResult
Updates a rule version resulting in a new rule version.
-
#update_variable(params = {}) ⇒ Struct
Updates a variable.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4046 4047 4048 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 4046 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4049 4050 4051 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 4049 def errors_module Errors end |
Instance Method Details
#batch_create_variable(params = {}) ⇒ Types::BatchCreateVariableResult
Creates a batch of variables.
528 529 530 531 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 528 def batch_create_variable(params = {}, = {}) req = build_request(:batch_create_variable, params) req.send_request() end |
#batch_get_variable(params = {}) ⇒ Types::BatchGetVariableResult
Gets a batch of variables.
570 571 572 573 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 570 def batch_get_variable(params = {}, = {}) req = build_request(:batch_get_variable, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 4029 4030 4031 4032 4033 4034 4035 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 4019 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::FraudDetector') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-frauddetector' context[:gem_version] = '1.86.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_batch_import_job(params = {}) ⇒ Struct
Cancels an in-progress batch import job.
595 596 597 598 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 595 def cancel_batch_import_job(params = {}, = {}) req = build_request(:cancel_batch_import_job, params) req.send_request() end |
#cancel_batch_prediction_job(params = {}) ⇒ Struct
Cancels the specified batch prediction job.
617 618 619 620 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 617 def cancel_batch_prediction_job(params = {}, = {}) req = build_request(:cancel_batch_prediction_job, params) req.send_request() end |
#create_batch_import_job(params = {}) ⇒ Struct
Creates a batch import job.
676 677 678 679 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 676 def create_batch_import_job(params = {}, = {}) req = build_request(:create_batch_import_job, params) req.send_request() end |
#create_batch_prediction_job(params = {}) ⇒ Struct
Creates a batch prediction job.
740 741 742 743 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 740 def create_batch_prediction_job(params = {}, = {}) req = build_request(:create_batch_prediction_job, params) req.send_request() end |
#create_detector_version(params = {}) ⇒ Types::CreateDetectorVersionResult
Creates a detector version. The detector version starts in a ‘DRAFT` status.
830 831 832 833 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 830 def create_detector_version(params = {}, = {}) req = build_request(:create_detector_version, params) req.send_request() end |
#create_list(params = {}) ⇒ Struct
Creates a list.
List is a set of input data for a variable in your event dataset. You use the input data in a rule that’s associated with your detector. For more information, see [Lists].
891 892 893 894 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 891 def create_list(params = {}, = {}) req = build_request(:create_list, params) req.send_request() end |
#create_model(params = {}) ⇒ Struct
Creates a model using the specified model type.
934 935 936 937 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 934 def create_model(params = {}, = {}) req = build_request(:create_model, params) req.send_request() end |
#create_model_version(params = {}) ⇒ Types::CreateModelVersionResult
Creates a version of the model using the specified model type and model id.
1016 1017 1018 1019 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 1016 def create_model_version(params = {}, = {}) req = build_request(:create_model_version, params) req.send_request() end |
#create_rule(params = {}) ⇒ Types::CreateRuleResult
Creates a rule for use with the specified detector.
1075 1076 1077 1078 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 1075 def create_rule(params = {}, = {}) req = build_request(:create_rule, params) req.send_request() end |
#create_variable(params = {}) ⇒ Struct
Creates a variable.
1139 1140 1141 1142 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 1139 def create_variable(params = {}, = {}) req = build_request(:create_variable, params) req.send_request() end |
#delete_batch_import_job(params = {}) ⇒ Struct
Deletes the specified batch import job ID record. This action does not delete the data that was batch imported.
1162 1163 1164 1165 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 1162 def delete_batch_import_job(params = {}, = {}) req = build_request(:delete_batch_import_job, params) req.send_request() end |
#delete_batch_prediction_job(params = {}) ⇒ Struct
Deletes a batch prediction job.
1184 1185 1186 1187 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 1184 def delete_batch_prediction_job(params = {}, = {}) req = build_request(:delete_batch_prediction_job, params) req.send_request() end |
#delete_detector(params = {}) ⇒ Struct
Deletes the detector. Before deleting a detector, you must first delete all detector versions and rule versions associated with the detector.
When you delete a detector, Amazon Fraud Detector permanently deletes the detector and the data is no longer stored in Amazon Fraud Detector.
1212 1213 1214 1215 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 1212 def delete_detector(params = {}, = {}) req = build_request(:delete_detector, params) req.send_request() end |
#delete_detector_version(params = {}) ⇒ Struct
Deletes the detector version. You cannot delete detector versions that are in ‘ACTIVE` status.
When you delete a detector version, Amazon Fraud Detector permanently deletes the detector and the data is no longer stored in Amazon Fraud Detector.
1243 1244 1245 1246 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 1243 def delete_detector_version(params = {}, = {}) req = build_request(:delete_detector_version, params) req.send_request() end |
#delete_entity_type(params = {}) ⇒ Struct
Deletes an entity type.
You cannot delete an entity type that is included in an event type.
When you delete an entity type, Amazon Fraud Detector permanently deletes that entity type and the data is no longer stored in Amazon Fraud Detector.
1271 1272 1273 1274 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 1271 def delete_entity_type(params = {}, = {}) req = build_request(:delete_entity_type, params) req.send_request() end |
#delete_event(params = {}) ⇒ Struct
Deletes the specified event.
When you delete an event, Amazon Fraud Detector permanently deletes that event and the event data is no longer stored in Amazon Fraud Detector. If ‘deleteAuditHistory` is `True`, event data is available through search for up to 30 seconds after the delete operation is completed.
1308 1309 1310 1311 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 1308 def delete_event(params = {}, = {}) req = build_request(:delete_event, params) req.send_request() end |
#delete_event_type(params = {}) ⇒ Struct
Deletes an event type.
You cannot delete an event type that is used in a detector or a model.
When you delete an event type, Amazon Fraud Detector permanently deletes that event type and the data is no longer stored in Amazon Fraud Detector.
1336 1337 1338 1339 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 1336 def delete_event_type(params = {}, = {}) req = build_request(:delete_event_type, params) req.send_request() end |
#delete_events_by_event_type(params = {}) ⇒ Types::DeleteEventsByEventTypeResult
Deletes all events of a particular event type.
1366 1367 1368 1369 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 1366 def delete_events_by_event_type(params = {}, = {}) req = build_request(:delete_events_by_event_type, params) req.send_request() end |
#delete_external_model(params = {}) ⇒ Struct
Removes a SageMaker model from Amazon Fraud Detector.
You can remove an Amazon SageMaker model if it is not associated with a detector version. Removing a SageMaker model disconnects it from Amazon Fraud Detector, but the model remains available in SageMaker.
1392 1393 1394 1395 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 1392 def delete_external_model(params = {}, = {}) req = build_request(:delete_external_model, params) req.send_request() end |
#delete_label(params = {}) ⇒ Struct
Deletes a label.
You cannot delete labels that are included in an event type in Amazon Fraud Detector.
You cannot delete a label assigned to an event ID. You must first delete the relevant event ID.
When you delete a label, Amazon Fraud Detector permanently deletes that label and the data is no longer stored in Amazon Fraud Detector.
1423 1424 1425 1426 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 1423 def delete_label(params = {}, = {}) req = build_request(:delete_label, params) req.send_request() end |
#delete_list(params = {}) ⇒ Struct
Deletes the list, provided it is not used in a rule.
When you delete a list, Amazon Fraud Detector permanently deletes that list and the elements in the list.
1448 1449 1450 1451 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 1448 def delete_list(params = {}, = {}) req = build_request(:delete_list, params) req.send_request() end |
#delete_model(params = {}) ⇒ Struct
Deletes a model.
You can delete models and model versions in Amazon Fraud Detector, provided that they are not associated with a detector version.
When you delete a model, Amazon Fraud Detector permanently deletes that model and the data is no longer stored in Amazon Fraud Detector.
1480 1481 1482 1483 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 1480 def delete_model(params = {}, = {}) req = build_request(:delete_model, params) req.send_request() end |
#delete_model_version(params = {}) ⇒ Struct
Deletes a model version.
You can delete models and model versions in Amazon Fraud Detector, provided that they are not associated with a detector version.
When you delete a model version, Amazon Fraud Detector permanently deletes that model version and the data is no longer stored in Amazon Fraud Detector.
1517 1518 1519 1520 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 1517 def delete_model_version(params = {}, = {}) req = build_request(:delete_model_version, params) req.send_request() end |
#delete_outcome(params = {}) ⇒ Struct
Deletes an outcome.
You cannot delete an outcome that is used in a rule version.
When you delete an outcome, Amazon Fraud Detector permanently deletes that outcome and the data is no longer stored in Amazon Fraud Detector.
1545 1546 1547 1548 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 1545 def delete_outcome(params = {}, = {}) req = build_request(:delete_outcome, params) req.send_request() end |
#delete_rule(params = {}) ⇒ Struct
Deletes the rule. You cannot delete a rule if it is used by an ‘ACTIVE` or `INACTIVE` detector version.
When you delete a rule, Amazon Fraud Detector permanently deletes that rule and the data is no longer stored in Amazon Fraud Detector.
1575 1576 1577 1578 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 1575 def delete_rule(params = {}, = {}) req = build_request(:delete_rule, params) req.send_request() end |
#delete_variable(params = {}) ⇒ Struct
Deletes a variable.
You can’t delete variables that are included in an event type in Amazon Fraud Detector.
Amazon Fraud Detector automatically deletes model output variables and SageMaker model output variables when you delete the model. You can’t delete these variables manually.
When you delete a variable, Amazon Fraud Detector permanently deletes that variable and the data is no longer stored in Amazon Fraud Detector.
1608 1609 1610 1611 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 1608 def delete_variable(params = {}, = {}) req = build_request(:delete_variable, params) req.send_request() end |
#describe_detector(params = {}) ⇒ Types::DescribeDetectorResult
Gets all versions for a specified detector.
1654 1655 1656 1657 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 1654 def describe_detector(params = {}, = {}) req = build_request(:describe_detector, params) req.send_request() end |
#describe_model_versions(params = {}) ⇒ Types::DescribeModelVersionsResult
Gets all of the model versions for the specified model type or for the specified model type and model ID. You can also get details for a single, specified model version.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1782 1783 1784 1785 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 1782 def describe_model_versions(params = {}, = {}) req = build_request(:describe_model_versions, params) req.send_request() end |
#get_batch_import_jobs(params = {}) ⇒ Types::GetBatchImportJobsResult
Gets all batch import jobs or a specific job of the specified ID. This is a paginated API. If you provide a null ‘maxResults`, this action retrieves a maximum of 50 records per page. If you provide a `maxResults`, the value must be between 1 and 50. To get the next page results, provide the pagination token from the `GetBatchImportJobsResponse` as part of your request. A null pagination token fetches the records from the beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1841 1842 1843 1844 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 1841 def get_batch_import_jobs(params = {}, = {}) req = build_request(:get_batch_import_jobs, params) req.send_request() end |
#get_batch_prediction_jobs(params = {}) ⇒ Types::GetBatchPredictionJobsResult
Gets all batch prediction jobs or a specific job if you specify a job ID. This is a paginated API. If you provide a null maxResults, this action retrieves a maximum of 50 records per page. If you provide a maxResults, the value must be between 1 and 50. To get the next page results, provide the pagination token from the GetBatchPredictionJobsResponse as part of your request. A null pagination token fetches the records from the beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1902 1903 1904 1905 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 1902 def get_batch_prediction_jobs(params = {}, = {}) req = build_request(:get_batch_prediction_jobs, params) req.send_request() end |
#get_delete_events_by_event_type_status(params = {}) ⇒ Types::GetDeleteEventsByEventTypeStatusResult
Retrieves the status of a ‘DeleteEventsByEventType` action.
1932 1933 1934 1935 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 1932 def get_delete_events_by_event_type_status(params = {}, = {}) req = build_request(:get_delete_events_by_event_type_status, params) req.send_request() end |
#get_detector_version(params = {}) ⇒ Types::GetDetectorVersionResult
Gets a particular detector version.
1992 1993 1994 1995 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 1992 def get_detector_version(params = {}, = {}) req = build_request(:get_detector_version, params) req.send_request() end |
#get_detectors(params = {}) ⇒ Types::GetDetectorsResult
Gets all detectors or a single detector if a ‘detectorId` is specified. This is a paginated API. If you provide a null `maxResults`, this action retrieves a maximum of 10 records per page. If you provide a `maxResults`, the value must be between 5 and 10. To get the next page results, provide the pagination token from the `GetDetectorsResponse` as part of your request. A null pagination token fetches the records from the beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2044 2045 2046 2047 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 2044 def get_detectors(params = {}, = {}) req = build_request(:get_detectors, params) req.send_request() end |
#get_entity_types(params = {}) ⇒ Types::GetEntityTypesResult
Gets all entity types or a specific entity type if a name is specified. This is a paginated API. If you provide a null ‘maxResults`, this action retrieves a maximum of 10 records per page. If you provide a `maxResults`, the value must be between 5 and 10. To get the next page results, provide the pagination token from the `GetEntityTypesResponse` as part of your request. A null pagination token fetches the records from the beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2095 2096 2097 2098 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 2095 def get_entity_types(params = {}, = {}) req = build_request(:get_entity_types, params) req.send_request() end |
#get_event(params = {}) ⇒ Types::GetEventResult
Retrieves details of events stored with Amazon Fraud Detector. This action does not retrieve prediction results.
2137 2138 2139 2140 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 2137 def get_event(params = {}, = {}) req = build_request(:get_event, params) req.send_request() end |
#get_event_prediction(params = {}) ⇒ Types::GetEventPredictionResult
Evaluates an event against a detector version. If a version ID is not provided, the detector’s (‘ACTIVE`) version is used.
2250 2251 2252 2253 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 2250 def get_event_prediction(params = {}, = {}) req = build_request(:get_event_prediction, params) req.send_request() end |
#get_event_prediction_metadata(params = {}) ⇒ Types::GetEventPredictionMetadataResult
Gets details of the past fraud predictions for the specified event ID, event type, detector ID, and detector version ID that was generated in the specified time period.
2367 2368 2369 2370 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 2367 def (params = {}, = {}) req = build_request(:get_event_prediction_metadata, params) req.send_request() end |
#get_event_types(params = {}) ⇒ Types::GetEventTypesResult
Gets all event types or a specific event type if name is provided. This is a paginated API. If you provide a null ‘maxResults`, this action retrieves a maximum of 10 records per page. If you provide a `maxResults`, the value must be between 5 and 10. To get the next page results, provide the pagination token from the `GetEventTypesResponse` as part of your request. A null pagination token fetches the records from the beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2431 2432 2433 2434 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 2431 def get_event_types(params = {}, = {}) req = build_request(:get_event_types, params) req.send_request() end |
#get_external_models(params = {}) ⇒ Types::GetExternalModelsResult
Gets the details for one or more Amazon SageMaker models that have been imported into the service. This is a paginated API. If you provide a null ‘maxResults`, this actions retrieves a maximum of 10 records per page. If you provide a `maxResults`, the value must be between 5 and 10. To get the next page results, provide the pagination token from the `GetExternalModelsResult` as part of your request. A null pagination token fetches the records from the beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2494 2495 2496 2497 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 2494 def get_external_models(params = {}, = {}) req = build_request(:get_external_models, params) req.send_request() end |
#get_kms_encryption_key(params = {}) ⇒ Types::GetKMSEncryptionKeyResult
Gets the encryption key if a KMS key has been specified to be used to encrypt content in Amazon Fraud Detector.
2514 2515 2516 2517 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 2514 def get_kms_encryption_key(params = {}, = {}) req = build_request(:get_kms_encryption_key, params) req.send_request() end |
#get_labels(params = {}) ⇒ Types::GetLabelsResult
Gets all labels or a specific label if name is provided. This is a paginated API. If you provide a null ‘maxResults`, this action retrieves a maximum of 50 records per page. If you provide a `maxResults`, the value must be between 10 and 50. To get the next page results, provide the pagination token from the `GetGetLabelsResponse` as part of your request. A null pagination token fetches the records from the beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2565 2566 2567 2568 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 2565 def get_labels(params = {}, = {}) req = build_request(:get_labels, params) req.send_request() end |
#get_list_elements(params = {}) ⇒ Types::GetListElementsResult
Gets all the elements in the specified list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2606 2607 2608 2609 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 2606 def get_list_elements(params = {}, = {}) req = build_request(:get_list_elements, params) req.send_request() end |
#get_lists_metadata(params = {}) ⇒ Types::GetListsMetadataResult
Gets the metadata of either all the lists under the account or the specified list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2653 2654 2655 2656 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 2653 def (params = {}, = {}) req = build_request(:get_lists_metadata, params) req.send_request() end |
#get_model_version(params = {}) ⇒ Types::GetModelVersionResult
Gets the details of the specified model version.
2712 2713 2714 2715 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 2712 def get_model_version(params = {}, = {}) req = build_request(:get_model_version, params) req.send_request() end |
#get_models(params = {}) ⇒ Types::GetModelsResult
Gets one or more models. Gets all models for the Amazon Web Services account if no model type and no model id provided. Gets all models for the Amazon Web Services account and model type, if the model type is specified but model id is not provided. Gets a specific model if (model type, model id) tuple is specified.
This is a paginated API. If you provide a null ‘maxResults`, this action retrieves a maximum of 10 records per page. If you provide a `maxResults`, the value must be between 1 and 10. To get the next page results, provide the pagination token from the response as part of your request. A null pagination token fetches the records from the beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2774 2775 2776 2777 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 2774 def get_models(params = {}, = {}) req = build_request(:get_models, params) req.send_request() end |
#get_outcomes(params = {}) ⇒ Types::GetOutcomesResult
Gets one or more outcomes. This is a paginated API. If you provide a null ‘maxResults`, this actions retrieves a maximum of 100 records per page. If you provide a `maxResults`, the value must be between 50 and
-
To get the next page results, provide the pagination token from
the ‘GetOutcomesResult` as part of your request. A null pagination token fetches the records from the beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2824 2825 2826 2827 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 2824 def get_outcomes(params = {}, = {}) req = build_request(:get_outcomes, params) req.send_request() end |
#get_rules(params = {}) ⇒ Types::GetRulesResult
Get all rules for a detector (paginated) if ‘ruleId` and `ruleVersion` are not specified. Gets all rules for the detector and the `ruleId` if present (paginated). Gets a specific rule if both the `ruleId` and the `ruleVersion` are specified.
This is a paginated API. Providing null maxResults results in retrieving maximum of 100 records per page. If you provide maxResults the value must be between 50 and 100. To get the next page result, a provide a pagination token from GetRulesResult as part of your request. Null pagination token fetches the records from the beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2892 2893 2894 2895 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 2892 def get_rules(params = {}, = {}) req = build_request(:get_rules, params) req.send_request() end |
#get_variables(params = {}) ⇒ Types::GetVariablesResult
Gets all of the variables or the specific variable. This is a paginated API. Providing null ‘maxSizePerPage` results in retrieving maximum of 100 records per page. If you provide `maxSizePerPage` the value must be between 50 and 100. To get the next page result, a provide a pagination token from `GetVariablesResult` as part of your request. Null pagination token fetches the records from the beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2946 2947 2948 2949 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 2946 def get_variables(params = {}, = {}) req = build_request(:get_variables, params) req.send_request() end |
#list_event_predictions(params = {}) ⇒ Types::ListEventPredictionsResult
Gets a list of past predictions. The list can be filtered by detector ID, detector version ID, event ID, event type, or by specifying a time period. If filter is not specified, the most recent prediction is returned.
For example, the following filter lists all past predictions for ‘xyz` event type - `{ “eventType”:{ “value”: “xyz” }” } `
This is a paginated API. If you provide a null ‘maxResults`, this action will retrieve a maximum of 10 records per page. If you provide a `maxResults`, the value must be between 50 and 100. To get the next page results, provide the `nextToken` from the response as part of your request. A null `nextToken` fetches the records from the beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3034 3035 3036 3037 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 3034 def list_event_predictions(params = {}, = {}) req = build_request(:list_event_predictions, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResult
Lists all tags associated with the resource. This is a paginated API. To get the next page results, provide the pagination token from the response as part of your request. A null pagination token fetches the records from the beginning.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3079 3080 3081 3082 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 3079 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_detector(params = {}) ⇒ Struct
Creates or updates a detector.
3118 3119 3120 3121 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 3118 def put_detector(params = {}, = {}) req = build_request(:put_detector, params) req.send_request() end |
#put_entity_type(params = {}) ⇒ Struct
Creates or updates an entity type. An entity represents who is performing the event. As part of a fraud prediction, you pass the entity ID to indicate the specific entity who performed the event. An entity type classifies the entity. Example classifications include customer, merchant, or account.
3157 3158 3159 3160 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 3157 def put_entity_type(params = {}, = {}) req = build_request(:put_entity_type, params) req.send_request() end |
#put_event_type(params = {}) ⇒ Struct
Creates or updates an event type. An event is a business activity that is evaluated for fraud risk. With Amazon Fraud Detector, you generate fraud predictions for events. An event type defines the structure for an event sent to Amazon Fraud Detector. This includes the variables sent as part of the event, the entity performing the event (such as a customer), and the labels that classify the event. Example event types include online payment transactions, account registrations, and authentications.
3224 3225 3226 3227 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 3224 def put_event_type(params = {}, = {}) req = build_request(:put_event_type, params) req.send_request() end |
#put_external_model(params = {}) ⇒ Struct
Creates or updates an Amazon SageMaker model endpoint. You can also use this action to update the configuration of the model endpoint, including the IAM role and/or the mapped variables.
3291 3292 3293 3294 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 3291 def put_external_model(params = {}, = {}) req = build_request(:put_external_model, params) req.send_request() end |
#put_kms_encryption_key(params = {}) ⇒ Struct
Specifies the KMS key to be used to encrypt content in Amazon Fraud Detector.
3317 3318 3319 3320 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 3317 def put_kms_encryption_key(params = {}, = {}) req = build_request(:put_kms_encryption_key, params) req.send_request() end |
#put_label(params = {}) ⇒ Struct
Creates or updates label. A label classifies an event as fraudulent or legitimate. Labels are associated with event types and used to train supervised machine learning models in Amazon Fraud Detector.
3354 3355 3356 3357 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 3354 def put_label(params = {}, = {}) req = build_request(:put_label, params) req.send_request() end |
#put_outcome(params = {}) ⇒ Struct
Creates or updates an outcome.
3389 3390 3391 3392 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 3389 def put_outcome(params = {}, = {}) req = build_request(:put_outcome, params) req.send_request() end |
#send_event(params = {}) ⇒ Struct
Stores events in Amazon Fraud Detector without generating fraud predictions for those events. For example, you can use ‘SendEvent` to upload a historical dataset, which you can then later use to train a model.
3450 3451 3452 3453 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 3450 def send_event(params = {}, = {}) req = build_request(:send_event, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Assigns tags to a resource.
3481 3482 3483 3484 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 3481 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
3507 3508 3509 3510 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 3507 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_detector_version(params = {}) ⇒ Struct
Updates a detector version. The detector version attributes that you can update include models, external model endpoints, rules, rule execution mode, and description. You can only update a ‘DRAFT` detector version.
3582 3583 3584 3585 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 3582 def update_detector_version(params = {}, = {}) req = build_request(:update_detector_version, params) req.send_request() end |
#update_detector_version_metadata(params = {}) ⇒ Struct
Updates the detector version’s description. You can update the metadata for any detector version (‘DRAFT, ACTIVE,` or `INACTIVE`).
3613 3614 3615 3616 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 3613 def (params = {}, = {}) req = build_request(:update_detector_version_metadata, params) req.send_request() end |
#update_detector_version_status(params = {}) ⇒ Struct
Updates the detector version’s status. You can perform the following promotions or demotions using ‘UpdateDetectorVersionStatus`: `DRAFT` to `ACTIVE`, `ACTIVE` to `INACTIVE`, and `INACTIVE` to `ACTIVE`.
3647 3648 3649 3650 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 3647 def update_detector_version_status(params = {}, = {}) req = build_request(:update_detector_version_status, params) req.send_request() end |
#update_event_label(params = {}) ⇒ Struct
Updates the specified event with a new label.
3682 3683 3684 3685 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 3682 def update_event_label(params = {}, = {}) req = build_request(:update_event_label, params) req.send_request() end |
#update_list(params = {}) ⇒ Struct
Updates a list.
3736 3737 3738 3739 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 3736 def update_list(params = {}, = {}) req = build_request(:update_list, params) req.send_request() end |
#update_model(params = {}) ⇒ Struct
Updates model description.
3766 3767 3768 3769 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 3766 def update_model(params = {}, = {}) req = build_request(:update_model, params) req.send_request() end |
#update_model_version(params = {}) ⇒ Types::UpdateModelVersionResult
Updates a model version. Updating a model version retrains an existing model version using updated training data and produces a new minor version of the model. You can update the training data set location and data access role attributes using this action. This action creates and trains a new minor version of the model, for example version 1.01, 1.02, 1.03.
3840 3841 3842 3843 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 3840 def update_model_version(params = {}, = {}) req = build_request(:update_model_version, params) req.send_request() end |
#update_model_version_status(params = {}) ⇒ Struct
Updates the status of a model version.
You can perform the following status updates:
-
Change the ‘TRAINING_IN_PROGRESS` status to `TRAINING_CANCELLED`.
-
Change the ‘TRAINING_COMPLETE` status to `ACTIVE`.
-
Change ‘ACTIVE` to `INACTIVE`.
3882 3883 3884 3885 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 3882 def update_model_version_status(params = {}, = {}) req = build_request(:update_model_version_status, params) req.send_request() end |
#update_rule_metadata(params = {}) ⇒ Struct
Updates a rule’s metadata. The description attribute can be updated.
3912 3913 3914 3915 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 3912 def (params = {}, = {}) req = build_request(:update_rule_metadata, params) req.send_request() end |
#update_rule_version(params = {}) ⇒ Types::UpdateRuleVersionResult
Updates a rule version resulting in a new rule version. Updates a rule version resulting in a new rule version (version 1, 2, 3 …).
3972 3973 3974 3975 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 3972 def update_rule_version(params = {}, = {}) req = build_request(:update_rule_version, params) req.send_request() end |
#update_variable(params = {}) ⇒ Struct
Updates a variable.
4010 4011 4012 4013 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 4010 def update_variable(params = {}, = {}) req = build_request(:update_variable, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4039 4040 4041 |
# File 'lib/aws-sdk-frauddetector/client.rb', line 4039 def waiter_names [] end |